@@ -4,13 +4,16 @@ from django.db import IntegrityError
 from django.shortcuts import render
 from django.utils.translation import ugettext_lazy as _
 
-from ..models.schoolyear import SchoolYear, SchoolYearPeriod
+from ..models.schoolyear import (
+    SchoolYear, SchoolYearDivision, SchoolYearPeriod,
+)
 from .filters import SchoolYearListFilter
 
 
+@admin.register(SchoolYear)
 class SchoolYearAdmin(admin.ModelAdmin):
-    list_display    = ('name', 'active')
-    list_editable   = ('active',)
+    list_display = ('name', 'active')
+    list_editable = ('active',)
 
     # do not allow to delete entries in admin
     def has_delete_permission(self, request, obj=None):
@@ -31,11 +34,12 @@ class SchoolYearPeriodInlineAdmin(admin.TabularInline):
     extra = 0
 
 
+@admin.register(SchoolYearDivision)
 class SchoolYearDivisionAdmin(admin.ModelAdmin):
-    actions         = ('copy_to_school_year',)
-    inlines         = (SchoolYearPeriodInlineAdmin,)
-    list_display    = ('name',)
-    list_filter     = (('school_year', SchoolYearListFilter),)
+    actions = ('copy_to_school_year',)
+    inlines = (SchoolYearPeriodInlineAdmin,)
+    list_display = ('name',)
+    list_filter = (('school_year', SchoolYearListFilter),)
 
     def copy_to_school_year(self, request, queryset):
         class SchoolYearForm(forms.Form):
