@@ -1,7 +1,7 @@
 from django.utils.translation import ugettext_lazy as _
 
-PRICE_DECIMAL_PLACES  = 2
-PRICE_MAX_DIGITS      = 10
+PRICE_DECIMAL_PLACES = 2
+PRICE_MAX_DIGITS = 10
 
 LEPRIKON_SHOW_SUBJECT_CODE = False
 
@@ -21,6 +21,10 @@ LEPRIKON_EVENT_TEMPLATES = (
     ('default', _('Default')),
 )
 
+LEPRIKON_ORDERABLE_TEMPLATES = (
+    ('default', _('Default')),
+)
+
 LEPRIKON_LEADER_TEMPLATES = (
     ('default', _('Default')),
 )
@@ -35,13 +39,19 @@ LEPRIKON_EVENTLIST_TEMPLATES = (
     ('grouped', _('Grouped by event groups')),
 )
 
+LEPRIKON_ORDERABLELIST_TEMPLATES = (
+    ('default', _('Default')),
+    ('grouped', _('Grouped by event groups')),
+)
+
 LEPRIKON_LEADERLIST_TEMPLATES = (
     ('default', _('Default')),
 )
 
-LEPRIKON_COLOR_POSITIVE = LEPRIKON_COLOR_PAID       = '#0a0'
-LEPRIKON_COLOR_NEGATIVE = LEPRIKON_COLOR_NOTPAID    = '#e00'
-LEPRIKON_COLOR_ZERO     = LEPRIKON_COLOR_OVERPAID   = '#00a'
+LEPRIKON_COLOR_POSITIVE = LEPRIKON_COLOR_PAID = '#0a0'
+LEPRIKON_COLOR_NEGATIVE = LEPRIKON_COLOR_NOTPAID = '#e60'
+LEPRIKON_COLOR_ZERO = LEPRIKON_COLOR_OVERPAID = '#00a'
+LEPRIKON_COLOR_OVERDUE = '#e00'
 
 LEPRIKON_QUESTION_FIELDS = {
     'boolean': {
@@ -68,11 +78,14 @@ LEPRIKON_QUESTION_FIELDS = {
 
 LEPRIKON_PARAM_BACK = 'zpet'
 
+LEPRIKON_URL = None
+
 LEPRIKON_URL_SUMMARY = 'prehled'
 LEPRIKON_URL_LEADER = 'pro-vedouci'
 LEPRIKON_URL_CREATE_ACCOUNT = 'novy-uzivatel'
 LEPRIKON_URL_COURSES = 'kurzy'
 LEPRIKON_URL_EVENTS = 'akce'
+LEPRIKON_URL_ORDERABLES = 'na-objednani'
 LEPRIKON_URL_LEADERS = 'vedouci'
 LEPRIKON_URL_MESSAGES = 'zpravy'
 LEPRIKON_URL_TIMESHEETS = 'vykazy'
@@ -81,6 +94,7 @@ LEPRIKON_URL_ENTRY = 'zaznam'
 LEPRIKON_URL_PARENT = 'zastupce'
 LEPRIKON_URL_PARTICIPANT = 'ucastnik'
 LEPRIKON_URL_PARTICIPANTS = 'ucastnici'
+LEPRIKON_URL_BILLING_INFO = 'fakturacni-udaje'
 LEPRIKON_URL_USER = 'uzivatel'
 LEPRIKON_URL_AGREEMENT = 'souhlas'
 LEPRIKON_URL_PASSWORD = 'heslo'
@@ -95,6 +109,7 @@ LEPRIKON_URL_JOURNALENTRY = 'zaznam-deniku'
 LEPRIKON_URL_MINE = 'moje'
 LEPRIKON_URL_ALTERNATING = 'zastup'
 LEPRIKON_URL_REPORTS = 'reporty'
+LEPRIKON_URL_PAYMENT_REQUEST = 'vyzva-k-platbe'
 LEPRIKON_URL_PAYMENTS = 'platby'
 LEPRIKON_URL_PAYMENTS_STATUS = 'stav-plateb'
 LEPRIKON_URL_DEBTORS = 'dluznici'
@@ -103,6 +118,7 @@ LEPRIKON_URL_DELETE = 'smazat'
 LEPRIKON_URL_CANCEL = 'zrusit'
 LEPRIKON_URL_REGISTRATION = 'prihlaska'
 LEPRIKON_URL_REGISTRATIONS = 'prihlasky'
+LEPRIKON_URL_REGISTRATION_LINK = 'prihlasovaci-odkaz'
 LEPRIKON_URL_TERMS_CONDITIONS = 'obchodni-podminky'
 LEPRIKON_URL_STATS = 'statistiky'
 LEPRIKON_URL_EMAIL = 'email'
