@@ -1,11 +1,11 @@
 from datetime import date
 
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 
 from .startend import StartEndMixin
+from .utils import change_year
 
 
 class SchoolYearManager(models.Manager):
@@ -24,18 +24,16 @@ class SchoolYearManager(models.Manager):
         return school_year
 
 
-
-@python_2_unicode_compatible
 class SchoolYear(models.Model):
-    year    = models.IntegerField(_('year'), unique=True, help_text=_('Only the first of the two years.'))
-    active  = models.BooleanField(_('active'), default=False)
+    year = models.IntegerField(_('year'), unique=True, help_text=_('Only the first of the two years.'))
+    active = models.BooleanField(_('active'), default=False)
 
     objects = SchoolYearManager()
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('-year',)
-        verbose_name        = _('school year')
+        app_label = 'leprikon'
+        ordering = ('-year',)
+        verbose_name = _('school year')
         verbose_name_plural = _('school years')
 
     def __str__(self):
@@ -51,18 +49,17 @@ class SchoolYear(models.Model):
         return '{}/{}'.format(self.year, self.year + 1)
 
 
-
-@python_2_unicode_compatible
 class SchoolYearDivision(models.Model):
-    school_year = models.ForeignKey(SchoolYear, verbose_name=_('school year'), related_name='divisions')
-    name        = models.CharField(_('division name'), max_length=150)
+    school_year = models.ForeignKey(SchoolYear, on_delete=models.CASCADE,
+                                    related_name='divisions', verbose_name=_('school year'))
+    name = models.CharField(_('division name'), max_length=150)
     period_name = models.CharField(_('period name'), max_length=150)
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('name',)
-        unique_together     = (('school_year', 'name'),)
-        verbose_name        = _('school year division')
+        app_label = 'leprikon'
+        ordering = ('name',)
+        unique_together = (('school_year', 'name'),)
+        verbose_name = _('school year division')
         verbose_name_plural = _('school year divisions')
 
     def __str__(self):
@@ -77,47 +74,45 @@ class SchoolYearDivision(models.Model):
         new.id, new.pk = None, None
         new.school_year = school_year
         new.save()
-        year_offset = school_year.year - old.school_year.year
+        year_delta = school_year.year - old.school_year.year
         periods = []
         for period in old.all_periods:
-            try:
-                start = date(period.start.year + year_offset, period.start.month, period.start.day)
-            except ValueError:
-                # handle leap-year
-                start = date(period.start.year + year_offset, period.start.month, period.start.day - 1)
-            try:
-                end   = date(period.end.year   + year_offset, period.end.month,   period.end.day)
-            except ValueError:
-                # handle leap-year
-                end   = date(period.end.year   + year_offset, period.end.month,   period.end.day - 1)
             periods.append(SchoolYearPeriod(
                 school_year_division=new,
                 name=period.name,
-                start=start,
-                end=end,
+                start=change_year(period.start, year_delta),
+                end=change_year(period.end, year_delta),
+                due_from=change_year(period.due_from, year_delta),
+                due_date=change_year(period.due_date, year_delta),
             ))
         SchoolYearPeriod.objects.bulk_create(periods)
         return new
 
+    def get_current_period(self):
+        return (
+            self.periods.filter(end__gte=date.today()).first() or
+            self.periods.last()
+        )
 
 
-@python_2_unicode_compatible
 class SchoolYearPeriod(StartEndMixin, models.Model):
-    school_year_division = models.ForeignKey(SchoolYearDivision, verbose_name=_('school year division'),
-                                             related_name='periods')
-    name        = models.CharField(_('name'), max_length=150)
-    start       = models.DateField(_('start date'))
-    end         = models.DateField(_('end date'))
+    school_year_division = models.ForeignKey(SchoolYearDivision, on_delete=models.CASCADE,
+                                             related_name='periods', verbose_name=_('school year division'))
+    name = models.CharField(_('name'), max_length=150)
+    start = models.DateField(_('start date'))
+    end = models.DateField(_('end date'))
+    due_from = models.DateField(_('due from'))
+    due_date = models.DateField(_('due date'))
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('start',)
-        verbose_name        = _('school year period')
+        app_label = 'leprikon'
+        ordering = ('start',)
+        verbose_name = _('school year period')
         verbose_name_plural = _('school year periods')
 
     def __str__(self):
         return _('{name}, {start:%m/%d %y} - {end:%m/%d %y}').format(
-            name    = self.name,
-            start   = self.start,
-            end     = self.end,
+            name=self.name,
+            start=self.start,
+            end=self.end,
         )
