@@ -2,10 +2,9 @@ import calendar
 from collections import namedtuple
 from datetime import date, datetime, timedelta
 
-from django.core.urlresolvers import reverse_lazy as reverse
 from django.db import models
+from django.urls import reverse_lazy as reverse
 from django.utils.dateformat import DateFormat
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 from djangocms_text_ckeditor.fields import HTMLField
@@ -18,28 +17,26 @@ def start_end_by_date(d):
     # we work with monthly timesheets by default
     # TODO: allow weekly and quarterly timesheets by settings
     return {
-        'start':    date(d.year, d.month, 1),
-        'end':      date(d.year, d.month, calendar.monthrange(d.year, d.month)[1]),
+        'start': date(d.year, d.month, 1),
+        'end': date(d.year, d.month, calendar.monthrange(d.year, d.month)[1]),
     }
 
 
-
 class TimesheetPeriodManager(models.Manager):
     def for_date(self, date):
         return self.get_or_create(**start_end_by_date(date))[0]
 
 
-@python_2_unicode_compatible
 class TimesheetPeriod(StartEndMixin, models.Model):
-    start   = models.DateField(_('start date'), editable=False, unique=True)
-    end     = models.DateField(_('end date'), editable=False, unique=True)
+    start = models.DateField(_('start date'), editable=False, unique=True)
+    end = models.DateField(_('end date'), editable=False, unique=True)
 
     objects = TimesheetPeriodManager()
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('-start',)
-        verbose_name        = _('timesheet period')
+        app_label = 'leprikon'
+        ordering = ('-start',)
+        verbose_name = _('timesheet period')
         verbose_name_plural = _('timesheet periods')
 
     def __str__(self):
@@ -56,38 +53,36 @@ class TimesheetPeriod(StartEndMixin, models.Model):
         return list(self.timesheets.all())
 
 
-
 class TimesheetManager(models.Manager):
 
     def for_leader_and_date(self, leader, date):
         return self.get_or_create(
-            leader  = leader,
-            period  = TimesheetPeriod.objects.for_date(date),
+            leader=leader,
+            period=TimesheetPeriod.objects.for_date(date),
         )[0]
 
 
-@python_2_unicode_compatible
 class Timesheet(models.Model):
-    period      = models.ForeignKey(TimesheetPeriod, verbose_name=_('period'), editable=False,
-                                    related_name='timesheets', on_delete=models.PROTECT)
-    leader      = models.ForeignKey(Leader, verbose_name=_('leader'), editable=False,
-                                    related_name='timesheets', on_delete=models.PROTECT)
-    submitted   = models.BooleanField(_('submitted'), default=False)
-    paid        = models.BooleanField(_('paid'), default=False)
+    period = models.ForeignKey(TimesheetPeriod, verbose_name=_('period'), editable=False,
+                               related_name='timesheets', on_delete=models.PROTECT)
+    leader = models.ForeignKey(Leader, verbose_name=_('leader'), editable=False,
+                               related_name='timesheets', on_delete=models.PROTECT)
+    submitted = models.BooleanField(_('submitted'), default=False)
+    paid = models.BooleanField(_('paid'), default=False)
 
-    objects     = TimesheetManager()
+    objects = TimesheetManager()
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('-period__start',)
-        unique_together     = (('period', 'leader'),)
-        verbose_name        = _('timesheet')
+        app_label = 'leprikon'
+        ordering = ('-period__start',)
+        unique_together = (('period', 'leader'),)
+        verbose_name = _('timesheet')
         verbose_name_plural = _('timesheets')
 
     def __str__(self):
         return '{leader}, {period}'.format(
-            leader  = self.leader,
-            period  = self.period.name,
+            leader=self.leader,
+            period=self.period.name,
         )
 
     @cached_property
@@ -116,45 +111,41 @@ class Timesheet(models.Model):
         for entry in self.all_entries:
             if entry.group not in gs:
                 gs[entry.group] = self.EntryGroup(
-                    name = entry.group.name,
-                    entries = [],
+                    name=entry.group.name,
+                    entries=[],
                 )
             gs[entry.group].entries.append(entry)
         return list(gs.values())
 
 
-
-@python_2_unicode_compatible
 class TimesheetEntryType(models.Model):
-    name    = models.CharField(_('name'), max_length=150)
-    order   = models.IntegerField(_('order'), blank=True, default=0)
+    name = models.CharField(_('name'), max_length=150)
+    order = models.IntegerField(_('order'), blank=True, default=0)
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('order',)
-        verbose_name        = _('timesheet entry type')
+        app_label = 'leprikon'
+        ordering = ('order',)
+        verbose_name = _('timesheet entry type')
         verbose_name_plural = _('timesheet entry types')
 
     def __str__(self):
         return self.name
 
 
-
-@python_2_unicode_compatible
 class TimesheetEntry(StartEndMixin, models.Model):
-    timesheet   = models.ForeignKey(Timesheet, verbose_name=_('timesheet'), editable=False,
-                                    related_name='timesheet_entries', on_delete=models.PROTECT)
-    entry_type  = models.ForeignKey(TimesheetEntryType, verbose_name=_('entry type'), null=True,
-                                    related_name='entries', on_delete=models.PROTECT)
-    date        = models.DateField(_('date'))
-    start       = models.TimeField(_('start time'))
-    end         = models.TimeField(_('end time'))
+    timesheet = models.ForeignKey(Timesheet, verbose_name=_('timesheet'), editable=False,
+                                  related_name='timesheet_entries', on_delete=models.PROTECT)
+    entry_type = models.ForeignKey(TimesheetEntryType, verbose_name=_('entry type'), null=True,
+                                   related_name='entries', on_delete=models.PROTECT)
+    date = models.DateField(_('date'))
+    start = models.TimeField(_('start time'))
+    end = models.TimeField(_('end time'))
     description = HTMLField(_('work description'))
 
     class Meta:
-        app_label           = 'leprikon'
-        ordering            = ('start',)
-        verbose_name        = _('timesheet entry')
+        app_label = 'leprikon'
+        ordering = ('start',)
+        verbose_name = _('timesheet entry')
         verbose_name_plural = _('timesheet entries')
 
     def __str__(self):
