@@ -1,19 +1,25 @@
 import locale
 import os
+import re
 import string
 import unicodedata
 import zlib
 from datetime import date
-from urllib.parse import urlencode
+from urllib.parse import parse_qs, urlencode
 
 from django.core.exceptions import ObjectDoesNotExist
-from django.core.urlresolvers import reverse_lazy as reverse
 from django.db import IntegrityError, transaction
+from django.urls import reverse_lazy as reverse
 from django.utils.encoding import iri_to_uri, smart_text
+from django.utils.functional import lazy
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 from .conf import settings
 
+MALE = 'm'
+FEMALE = 'f'
+
 
 def _get_localeconv():
     """
@@ -125,7 +131,22 @@ def url_back(request):
     )
 
 
+recursive_back_splitter = re.compile(f'[?&]{settings.LEPRIKON_PARAM_BACK}=')
+
+
 def url_with_back(url, url_back):
+    try:
+        query = url_back.split('?')[1]
+    except IndexError:
+        pass
+    else:
+        try:
+            # try to reuse original back url
+            url_back = parse_qs(query)[settings.LEPRIKON_PARAM_BACK][0]
+        except KeyError:
+            pass
+    # remove recursive back url
+    url_back = recursive_back_splitter.split(url_back)[0]
     return '{}?{}'.format(url, urlencode({settings.LEPRIKON_PARAM_BACK: iri_to_uri(url_back)}))
 
 
@@ -133,6 +154,10 @@ def reverse_with_back(request, *args, **kwargs):
     return url_with_back(reverse(*args, **kwargs), current_url(request))
 
 
+def get_gender(birth_num):
+    return FEMALE if birth_num[2:4] > '50' else MALE
+
+
 def get_birth_date(birth_num):
     birth_num = birth_num.replace('/', '')
     y = int(birth_num[:2])
@@ -153,7 +178,11 @@ def get_birth_date(birth_num):
 
 def get_age(birth_date, today=None):
     today = today or date.today()
-    if date(today.year, birth_date.month, birth_date.day) > today:
+    try:
+        birth_day_this_year = date(today.year, birth_date.month, birth_date.day)
+    except ValueError:
+        birth_day_this_year = date(today.year, birth_date.month + 1, 1)
+    if birth_day_this_year > today:
         return today.year - birth_date.year - 1
     else:
         return today.year - birth_date.year
@@ -226,6 +255,9 @@ def merge_users(source, target):
     except AttributeError:
         pass
 
+    from rocketchat import RocketChat
+    RocketChat().merge_users(source, target)
+
     source.delete()
 
 
@@ -236,3 +268,14 @@ def spayd(*items):
     )
     s += '*CRC32:%x' % zlib.crc32(s.encode())
     return s.upper()
+
+
+def paragraph(text):
+    return mark_safe(
+        f'<p>{text.strip()}</p>'
+        .replace('\n', '<br/>\n')
+        .replace('<br/>\n<br/>\n', '</p>\n\n<p>')
+    )
+
+
+lazy_paragraph = lazy(paragraph, str)
