@@ -1,15 +1,17 @@
-from django.core.urlresolvers import reverse_lazy as reverse
+from cms.views import details as cms_view_details
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404, redirect
+from django.urls import reverse_lazy as reverse
 from django.utils.translation import ugettext_lazy as _
 
 from ..forms.subjects import (
-    CourseRegistrationForm, EventRegistrationForm, SubjectFilterForm,
-    SubjectForm,
+    CourseRegistrationForm, EventRegistrationForm, OrderableRegistrationForm,
+    SubjectFilterForm, SubjectForm,
 )
 from ..models.courses import Course
 from ..models.events import Event
 from ..models.leprikonsite import LeprikonSite
+from ..models.orderables import Orderable
 from ..models.subjects import (
     Subject, SubjectPayment, SubjectRegistration, SubjectType,
 )
@@ -19,12 +21,24 @@ from .generic import (
 )
 
 
-class SubjectTypeMixin(object):
+class SubjectTypeMixin:
     _models = {
         SubjectType.COURSE: Course,
-        SubjectType.EVENT:  Event,
+        SubjectType.EVENT: Event,
+        SubjectType.ORDERABLE: Orderable,
     }
 
+    def dispatch(self, request, subject_type, *args, **kwargs):
+        self.subject_type = get_object_or_404(SubjectType, slug=subject_type)
+        self.model = self._models[self.subject_type.subject_type]
+        return super().dispatch(request, *args, **kwargs)
+
+    def get_placeholder(self):
+        return super().get_placeholder() + ':' + self.subject_type.slug
+
+    def get_queryset(self):
+        return super().get_queryset().filter(subject_type=self.subject_type)
+
     def get_template_names(self):
         return [
             'leprikon/{}{}.html'.format(self.subject_type.slug, self.template_name_suffix),
@@ -32,47 +46,54 @@ class SubjectTypeMixin(object):
             'leprikon/subject{}.html'.format(self.template_name_suffix),
         ]
 
-    def dispatch(self, request, subject_type, *args, **kwargs):
-        self.subject_type = get_object_or_404(SubjectType, slug=subject_type)
-        self.model = self._models[self.subject_type.subject_type]
-        return super(SubjectTypeMixin, self).dispatch(request, **kwargs)
 
-    def get_queryset(self):
-        return super(SubjectTypeMixin, self).get_queryset().filter(subject_type=self.subject_type)
+class CMSSubjectTypeMixin(SubjectTypeMixin):
+    def dispatch(self, request, *args, **kwargs):
+        # Get current CMS Page
+        cms_page = request.current_page.get_public_object()
+
+        # Check whether it really is a Leprikon subject type application.
+        # It might also be one of its sub-pages.
+        if cms_page.application_urls != 'LeprikonSubjectTypeApp':
+            # In such case show regular CMS Page
+            return cms_view_details(request, *args, **kwargs)
+        return super(CMSSubjectTypeMixin, self).dispatch(request, cms_page.application_namespace, **kwargs)
 
 
-
-class SubjectListView(SubjectTypeMixin, FilteredListView):
-    form_class          = SubjectFilterForm
-    preview_template    = 'leprikon/subject_preview.html'
-    paginate_by         = 10
+class SubjectListBaseView(FilteredListView):
+    form_class = SubjectFilterForm
+    preview_template = 'leprikon/subject_preview.html'
+    paginate_by = 10
 
     def get_title(self):
         return _('{subject_type} in school year {school_year}').format(
-            subject_type    = self.subject_type.plural,
-            school_year     = self.request.school_year,
+            subject_type=self.subject_type.plural,
+            school_year=self.request.school_year,
         )
 
     def get_message_empty(self):
         return _('No {subject_type} matching given search parameters found.').format(
-            subject_type = self.subject_type.plural,
+            subject_type=self.subject_type.plural,
         )
 
     def get_form(self):
         return self.form_class(
-            subject_type_type   = self.subject_type.subject_type,
-            subject_types       = [self.subject_type],
-            school_year         = self.request.school_year,
-            is_staff            = self.request.user.is_staff,
-            data                = self.request.GET,
+            subject_type_type=self.subject_type.subject_type,
+            subject_types=[self.subject_type],
+            school_year=self.request.school_year,
+            is_staff=self.request.user.is_staff,
+            data=self.request.GET,
         )
 
     def get_queryset(self):
         return self.get_form().get_queryset()
 
 
+class SubjectListView(CMSSubjectTypeMixin, SubjectListBaseView):
+    pass
 
-class SubjectListMineView(SubjectListView):
+
+class SubjectListMineView(SubjectTypeMixin, SubjectListBaseView):
 
     def get_template_names(self):
         return [
@@ -83,16 +104,15 @@ class SubjectListMineView(SubjectListView):
 
     def get_title(self):
         return _('My {subject_type} in school year {school_year}').format(
-            subject_type = self.subject_type.plural,
-            school_year = self.request.school_year,
+            subject_type=self.subject_type.plural,
+            school_year=self.request.school_year,
         )
 
     def get_queryset(self):
         return super(SubjectListMineView, self).get_queryset().filter(leaders=self.request.leader)
 
 
-
-class SubjectDetailView(SubjectTypeMixin, DetailView):
+class SubjectDetailView(CMSSubjectTypeMixin, DetailView):
 
     def get_queryset(self):
         qs = super(SubjectDetailView, self).get_queryset()
@@ -101,7 +121,6 @@ class SubjectDetailView(SubjectTypeMixin, DetailView):
         return qs
 
 
-
 class SubjectRegistrationsView(SubjectTypeMixin, DetailView):
     template_name_suffix = '_registrations'
 
@@ -118,18 +137,18 @@ class SubjectRegistrationsView(SubjectTypeMixin, DetailView):
 
 
 class SubjectUpdateView(SubjectTypeMixin, UpdateView):
-    form_class  = SubjectForm
+    form_class = SubjectForm
 
     def get_title(self):
         return _('Change {subject_type} {subject}').format(
-            subject_type = self.subject_type.name_akuzativ,
-            subject = self.object.name,
+            subject_type=self.subject_type.name_akuzativ,
+            subject=self.object.name,
         )
 
     def get_message(self):
         return _('The changes in {subject_type} {subject} have been saved.').format(
-            subject_type = self.subject_type.name_genitiv,
-            subject = self.object.name,
+            subject_type=self.subject_type.name_genitiv,
+            subject=self.object.name,
         )
 
     def get_queryset(self):
@@ -139,64 +158,54 @@ class SubjectUpdateView(SubjectTypeMixin, UpdateView):
         return qs
 
 
-
-class SubjectRegistrationFormView(CreateView):
-    back_url        = reverse('leprikon:registration_list')
-    submit_label    = _('Submit registration')
-    message         = _('The registration has been saved. We will inform you about its further processing.')
-    _models = {
-        SubjectType.COURSE: Course,
-        SubjectType.EVENT:  Event,
-    }
-    _form_classes = {
-        SubjectType.COURSE: CourseRegistrationForm,
-        SubjectType.EVENT:  EventRegistrationForm,
-    }
-
-    def get_template_names(self):
-        return [
-            'leprikon/{}_registration_form.html'.format(self.subject_type.slug, self.template_name_suffix),
-            'leprikon/{}_registration_form.html'.format(self.subject_type.subject_type, self.template_name_suffix),
-            'leprikon/subject_registration_form.html'.format(self.template_name_suffix),
-        ]
-
-    def get_title(self):
-        return _('Registration for {subject_type} {subject}').format(
-            subject_type = self.subject_type.name_akuzativ,
-            subject = self.subject.name,
-        )
-
-    def dispatch(self, request, subject_type, pk, **kwargs):
-        self.subject_type = get_object_or_404(SubjectType, slug=subject_type)
-        lookup_kwargs = {
-            'subject_type': self.subject_type,
-            'id':           int(pk),
-        }
+class SubjectMixin:
+    def dispatch(self, request, pk, **kwargs):
+        lookup_kwargs = {'subject_type': self.subject_type, 'id': int(pk)}
         if not self.request.user.is_staff:
             lookup_kwargs['public'] = True
         self.subject = get_object_or_404(Subject, **lookup_kwargs)
         if not self.subject.registration_allowed:
             return redirect(self.subject)
         self.request.school_year = self.subject.school_year
-        self.model = self._models[self.subject.subject_type.subject_type]
-        return super(SubjectRegistrationFormView, self).dispatch(request, **kwargs)
+        return super().dispatch(request, **kwargs)
+
+
+class SubjectRegistrationFormBaseView(CreateView):
+    back_url = reverse('leprikon:registration_list')
+    submit_label = _('Submit registration')
+    message = _('The registration has been saved. We will inform you about its further processing.')
+    template_name_suffix = '_registration_form'
+    _form_classes = {
+        SubjectType.COURSE: CourseRegistrationForm,
+        SubjectType.EVENT: EventRegistrationForm,
+        SubjectType.ORDERABLE: OrderableRegistrationForm,
+    }
+
+    def get_title(self):
+        return _('Registration for {subject_type} {subject}').format(
+            subject_type=self.subject_type.name_akuzativ,
+            subject=self.subject.name,
+        )
 
     def get_form_class(self):
-        return self._form_classes[self.subject.subject_type.subject_type]
+        return self._form_classes[self.subject_type.subject_type]
 
     def get_form_kwargs(self):
-        kwargs  = super(SubjectRegistrationFormView, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['subject'] = self.subject
         kwargs['user'] = self.request.user
         return kwargs
 
 
+class SubjectRegistrationFormView(CMSSubjectTypeMixin, SubjectMixin, SubjectRegistrationFormBaseView):
+    pass
 
-class UserRegistrationMixin(object):
+
+class UserRegistrationMixin:
     model = SubjectRegistration
 
     def get_queryset(self):
-        return super(UserRegistrationMixin, self).get_queryset().filter(user=self.request.user)
+        return super().get_queryset().filter(user=self.request.user)
 
     def get_template_names(self):
         return [self.template_name] if self.template_name else [
@@ -208,25 +217,31 @@ class UserRegistrationMixin(object):
         ]
 
 
-
-class SubjectRegistrationPdfView(UserRegistrationMixin, DetailView):
+class PDFMixin:
+    event = 'pdf'
 
     def get(self, request, *args, **kwargs):
-        # get registration
-        registration = self.get_object()
-
-        # create PDF response object
+        obj = self.get_object()
         response = HttpResponse(content_type='application/pdf')
-        response['Content-Disposition'] = 'attachment; filename="{}"'.format(registration.pdf_filename)
+        response['Content-Disposition'] = 'attachment; filename="{}"'.format(obj.get_pdf_filename(self.event))
+        return obj.write_pdf(self.event, response)
 
-        # create basic pdf registration from rml template
-        return registration.write_pdf(response)
+
+class SubjectRegistrationPdfView(PDFMixin, UserRegistrationMixin, DetailView):
+    pass
+
+
+class SubjectRegistrationPaymentRequestView(PDFMixin, UserRegistrationMixin, DetailView):
+    event = 'payment_request'
 
 
 class SubjectRegistrationCancelView(UserRegistrationMixin, ConfirmUpdateView):
     template_name_suffix = '_cancel'
     title = _('Registration cancellation request')
 
+    def get_queryset(self):
+        return super().get_queryset().filter(canceled=None)
+
     def get_question(self):
         return _('Are you sure You want to cancel the registration "{}"?').format(self.object)
 
@@ -234,11 +249,14 @@ class SubjectRegistrationCancelView(UserRegistrationMixin, ConfirmUpdateView):
         return _('The cancellation request for {} has been saved.').format(self.object)
 
     def confirmed(self):
-        self.object.cancel_request = True
-        self.object.save()
+        if self.object.approved:
+            self.object.cancel_request = True
+            self.object.save()
+        else:
+            self.object.refuse()
 
 
-class UserPaymentMixin(object):
+class UserPaymentMixin:
     model = SubjectPayment
 
     def get_queryset(self):
@@ -255,14 +273,5 @@ class SubjectPaymentsListView(UserPaymentMixin, ListView):
         return _('Payments')
 
 
-class SubjectPaymentPdfView(UserPaymentMixin, DetailView):
-    def get(self, request, *args, **kwargs):
-        # get payment
-        payment = self.get_object()
-
-        # create PDF response object
-        response = HttpResponse(content_type='application/pdf')
-        response['Content-Disposition'] = 'attachment; filename="{}"'.format(payment.pdf_filename)
-
-        # create basic pdf payment from rml template
-        return payment.write_pdf(response)
+class SubjectPaymentPdfView(PDFMixin, UserPaymentMixin, DetailView):
+    pass
